==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "Network connection error: Could not connect to the document" : "Verkkoyhteysvirhe: ei voitu yhdistää asiakirjaan",
    "Retry" : "Yritä uudelleen",
    "Last save {lastSave}" : "Viimeisin tallennus {lastSave}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkyvät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert image" : "Lisää kuva",
    "Add link" : "Lisää linkki",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "Show image" : "Näytä kuva",
    "Show file" : "Näytä tiedosto",
    "New text document" : "Uusi tekstiasiakirja",
    "New text document.md" : "Uusi tekstiasiakirja.md",
    "Edit" : "Muokkaa",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Bold" : "Lihavoitu",
    "Italic" : "Kursivoitu",
    "Strikethrough" : "Yliviivattu",
    "Paragraph" : "Kappale",
    "Headings" : "Otsikot",
    "Heading 1" : "Otsikko 1",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Heading 6" : "Otsikko 6",
    "Code block" : "Koodilohko"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/fi.js <==
OC.L10N.register(
    "text",
    {
    "Text" : "Teksti",
    "📝 Collaborative document editing" : "📝 Yhteistyöhön perustuvaa asiakirjojen muokkausta",
    "Use current version" : "Käytä nykyistä versiota",
    "Use the saved version" : "Käytä tallennettua versiota",
    "Network connection error: Could not connect to the document" : "Verkkoyhteysvirhe: ei voitu yhdistää asiakirjaan",
    "Retry" : "Yritä uudelleen",
    "Last save {lastSave}" : "Viimeisin tallennus {lastSave}",
    "Unsaved changes" : "Tallentamattomia muutoksia",
    "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkyvät kuka muokkaa asiakirjaa",
    "Edit guest name" : "Muokkaa vieraan nimeä",
    "Save guest name" : "Tallenna vieraan nimi",
    "Insert image" : "Lisää kuva",
    "Add link" : "Lisää linkki",
    "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
    "Show image" : "Näytä kuva",
    "Show file" : "Näytä tiedosto",
    "New text document" : "Uusi tekstiasiakirja",
    "Edit" : "Muokkaa",
    "Undo" : "Kumoa",
    "Redo" : "Tee uudelleen",
    "Bold" : "Lihavoitu",
    "Italic" : "Kursivoitu",
    "Strikethrough" : "Yliviivattu",
    "Paragraph" : "Kappale",
    "Headings" : "Otsikot",
    "Heading 1" : "Otsikko 1",
    "Heading 2" : "Otsikko 2",
    "Heading 3" : "Otsikko 3",
    "Heading 4" : "Otsikko 4",
    "Heading 5" : "Otsikko 5",
    "Heading 6" : "Otsikko 6",
    "Unordered list" : "Järjestämätön lista",
    "Ordered list" : "Järjestetty lista",
    "Code block" : "Koodilohko",
    "New text document.md" : "Uusi tekstiasiakirja.md"
},
"nplurals=2; plural=(n != 1);");
